aboutsummaryrefslogtreecommitdiffstats
path: root/server/src/main/java/com/vaadin/event
diff options
context:
space:
mode:
authorAdam Wagner <wbadam@users.noreply.github.com>2017-05-11 22:49:19 +0300
committerPekka Hyvönen <pekka@vaadin.com>2017-05-11 22:49:19 +0300
commit494b90a81cdd7dfc2fb337676e51ffa4bdd6ea43 (patch)
treee3196df0dad644a3b6930575205b26cb36ff91cf /server/src/main/java/com/vaadin/event
parentbda8acb85610f1532b9f11a8a9530c694051c2d9 (diff)
downloadvaadin-framework-494b90a81cdd7dfc2fb337676e51ffa4bdd6ea43.tar.gz
vaadin-framework-494b90a81cdd7dfc2fb337676e51ffa4bdd6ea43.zip
Create upload URLs only when stream variable is attached by drop handler (#9301)
* Create upload URLs only when stream variable is attached by drop handler * Add file size limit to test ui and remove label drop target
Diffstat (limited to 'server/src/main/java/com/vaadin/event')
-rw-r--r--server/src/main/java/com/vaadin/event/dnd/FileDropEvent.java15
1 files changed, 8 insertions, 7 deletions
diff --git a/server/src/main/java/com/vaadin/event/dnd/FileDropEvent.java b/server/src/main/java/com/vaadin/event/dnd/FileDropEvent.java
index 42d270ebe4..7ad5f410bf 100644
--- a/server/src/main/java/com/vaadin/event/dnd/FileDropEvent.java
+++ b/server/src/main/java/com/vaadin/event/dnd/FileDropEvent.java
@@ -15,6 +15,7 @@
*/
package com.vaadin.event.dnd;
+import java.util.Collection;
import java.util.List;
import com.vaadin.ui.AbstractComponent;
@@ -22,7 +23,7 @@ import com.vaadin.ui.Component;
import com.vaadin.ui.Html5File;
/**
* File drop event that contains the list of files dropped on a file drop
* target.
*
* @param <T>
@@ -34,7 +35,7 @@ import com.vaadin.ui.Html5File;
public class FileDropEvent<T extends AbstractComponent> extends
Component.Event {
- private final List<Html5File> files;
+ private final Collection<Html5File> files;
/**
* Creates a file drop event.
@@ -42,21 +43,21 @@ public class FileDropEvent<T extends AbstractComponent> extends
* @param target
* The file drop target component.
* @param files
* List of files.
*/
- public FileDropEvent(T target, List<Html5File> files) {
+ public FileDropEvent(T target, Collection<Html5File> files) {
super(target);
this.files = files;
}
/**
* Gets the list of files dropped onto the file drop target component.
*
* @return List of files that were dropped onto the file drop target
* component.
*/
- public List<Html5File> getFiles() {
+ public Collection<Html5File> getFiles() {
return files;
}
}
@@ -22,7 +23,7 @@ import com.vaadin.ui.Component;
import com.vaadin.ui.Html5File;
/**
- * File drop event that contains the list of files dropped on a file drop
+ * File drop event that contains the collection of files dropped on a file drop
* target.
*
@@ -42,21 +43,21 @@ public class FileDropEvent<T extends AbstractComponent> extends
* The file drop target component.
* @param files
- * List of files.
+ * Collection of files.
*/
@@ -42,21 +43,21 @@ public class FileDropEvent<T extends AbstractComponent> extends
}
/**
- * Gets the list of files dropped onto the file drop target component.
+ * Gets the collection of files dropped onto the file drop target component.
*
@@ -42,21 +43,21 @@ public class FileDropEvent<T extends AbstractComponent> extends
*
- * @return List of files that were dropped onto the file drop target
+ * @return Collection of files that were dropped onto the file drop target
* component.
*/